@@ -103,7 +103,7 @@ RLayerListQt.prototype.updateLayers = function(documentInterface) {
     layer = doc.queryCurrentLayer();
     if (!layer.isNull()) {
         var list = this.findItems(layer.getName(), Qt.MatchExactly);
-        if (list.length != 0) {
+        if (list.length !== 0) {
             this.blockSignals(true);
             this.setCurrentItem(list[0]);
             this.blockSignals(false);
